/*
** 1999-03-16 -	Header for the configuration module dealing with controls. Real short.
*/

extern const CfgModule *	cct_describe(MainInfo *min);

